@@ -27,6 +27,8 @@ import mock
 import fs
 import fs.path
 import pytest
+import os
+import time
 
 from PyQt5 import QtWidgets, QtTest
 from conftest import ROOT_FS, TESTDATA_DIR, ROOT_DIR, SUB_DIRS, Dummy_Filepicker, force_dir
@@ -84,7 +86,7 @@ class Test_Open_FilePicker(object):
         self.window.action()
         _file_names = [list(name)[0] for name in self.window.file_list_items]
         assert fs.path.join(u"foo", u"foo.txt") in _file_names
-        assert len(self.window.file_list_items) == 1
+        assert len(self.window.file_list_items) == 2
 
     def test_showname_close(self):
         self.window.show_name()
@@ -177,7 +179,7 @@ class Test_Open_FilePicker(object):
         assert sel_name == u"bar/foo.txt"
         self.window.onCellClicked(0, 0)
         QtWidgets.QApplication.processEvents()
-        self.window.history_previous()
+        self.window.ui_DirList.setCurrentIndex(1)
         QtWidgets.QApplication.processEvents()
         _file_names = [list(name)[0] for name in self.window.file_list_items]
         result = sel_name in _file_names
@@ -199,6 +201,32 @@ class Test_Open_FilePicker(object):
         filename = u"{}{}{}".format(force_dir(ROOT_DIR), fs.path.forcedir(TESTDATA_DIR), u"example.csv")
         assert self.window.filename[7:] == filename
 
+    def test_filename_high_light_by_selectedname(self):
+        self.window.ui_SelectedName.setText(u'example.csv')
+        QtWidgets.QApplication.processEvents()
+        index = self.window.ui_FileList.selectedIndexes()[0].row()
+        assert index == 3
+        assert self.window.ui_Action.isEnabled()
+        index = sorted(SUB_DIRS).index(fs.path.join(u"testdata", u"foo"))
+        self.window.ui_FileList.selectRow(index)
+        QtWidgets.QApplication.processEvents()
+        self.window.onCellDoubleClicked(index, 0)
+        QtWidgets.QApplication.processEvents()
+        self.window.ui_SelectedName.setText(u'this.txt')
+        QtWidgets.QApplication.processEvents()
+        index = self.window.ui_FileList.selectedIndexes()[0].row()
+        assert index == 1
+        assert self.window.ui_Action.isEnabled()
+        self.window.ui_DirList.setCurrentIndex(1)
+        QtWidgets.QApplication.processEvents()
+        self.window.ui_SelectedName.setText(u'example.csv')
+        QtWidgets.QApplication.processEvents()
+        time.sleep(0.1)
+        index = self.window.ui_FileList.selectedIndexes()[0].row()
+        assert index == 3
+        assert self.window.ui_Action.isEnabled()
+        self.window.close()
+
 
 class Test_Save_FilePicker(object):
     def setup(self):
@@ -244,13 +272,12 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        self.window.ui_SelectedName.setText(u'foo.txt')
-        QtWidgets.QApplication.processEvents()
-        self.window.selection_name()
+        self.window.ui_SelectedName.setText(u'this.txt')
         QtWidgets.QApplication.processEvents()
+        time.sleep(0.1)
         index = self.window.ui_FileList.selectedIndexes()[0].row()
         self.window.close()
-        assert index == 0
+        assert index == 1
 
     def test_default_filename(self):
         self.window.default_filename = u"abc.txt"
@@ -267,13 +294,11 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        self.window.selection_directory()
         self.window.ui_SelectedName.setText(u"example.txt")
         QtWidgets.QApplication.processEvents()
         self.window.action()
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        assert list(self.window.wparm.value)[0] == u"empty"
         assert u"example.txt" in self.window.filename
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
@@ -288,6 +313,7 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.close()
         _folder_names = [list(name)[0] for name in self.window.dir_list_items]
+        os.rmdir(os.path.join(ROOT_DIR, TESTDATA_DIR, 'empty', 'exampledir'))
         assert fs.path.join(u"empty", u"exampledir") in _folder_names
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
@@ -297,18 +323,22 @@ class Test_Save_FilePicker(object):
         index = _folder_names.index(u'empty')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        self.window.history_previous()
+        self.window.ui_DirList.setCurrentIndex(1)
+        QtWidgets.QApplication.processEvents()
         index = _folder_names.index(u'bar')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        self.window.history_previous()
+        self.window.ui_DirList.setCurrentIndex(1)
+        QtWidgets.QApplication.processEvents()
         assert self.window.ui_DirList.currentText() == 'empty'
         QtWidgets.QApplication.processEvents()
         self.window.make_dir()
         QtWidgets.QApplication.processEvents()
         _folder_names = [list(name)[0] for name in self.window.dir_list_items]
         self.window.close()
-        assert fs.path.join(u"empty", u"thisexampledir") in _folder_names
+        valid = fs.path.join(u"empty", u"thisexampledir") in _folder_names
+        os.rmdir(os.path.join(ROOT_DIR, TESTDATA_DIR, 'empty', 'thisexampledir'))
+        assert valid
         assert self.window.last_dir_index == 1
 
 
