@@ -68,7 +68,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             fs_url = [fs_url] + [self.fs_home_url, self.fs_root_url]
         self.fs_url = fs_url[0]
         if isinstance(stored_fs_url, list):
-            for _fs_url in list(set(stored_fs_url + fs_url)):
+            for _fs_url in sorted(list(set(stored_fs_url + fs_url))):
                 if fs_url_exists(_fs_url):
                     self.ui_fs_serverlist.addItem(_fs_url)
         self.active_url = self.fs_url
@@ -181,7 +181,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.fs.close()
         try:
             self.fs = fs.open_fs(self.active_url)
-        except IOError:
+        except (IOError, fs.errors.CreateFailed):
             logging.error(u"{} does not exist!".format(self.active_url))
             exit()
         try:
@@ -225,8 +225,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         Fills the filenames based on file_type into a FileList, also directories
         """
+        self.wparm = None
         if not self.show_save_action:
-            self.ui_SelectedName.setText(None)
+            self.ui_SelectedName.setText(u"")
         QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)
         self.selected_dir = self.ui_DirList.currentText()
         self.ui_FileList.clearContents()
@@ -368,7 +369,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         if not self.show_save_action and not self.show_dirs_only:
             self.ui_Action.setEnabled(False)
         self.filename = self.ui_SelectedName.text()
-        dirname = fs.path.forcedir(u'.')
+        if self.ui_DirList.currentText() == self.active_url:
+            dirname = u""
+        else:
+            dirname = self.ui_DirList.currentText()
         if self.wparm is not None:
             _dirname = fs.path.forcedir(u'.')
             if self.wparm.value == u'{}{}'.format(_dirname, self.wparm.text):
@@ -432,10 +436,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         new_dir_name, ok = QtWidgets.QInputDialog.getText(self, u"New Folder", u"Enter a new folder name:",
                                                           QtWidgets.QLineEdit.Normal, "")
         if ok:
-            if self.wparm is None:
-                dirname = u''
+            if self.ui_DirList.currentText() == self.active_url:
+                dirname = u""
             else:
-                dirname = self.selected_dir
+                dirname = self.ui_DirList.currentText()
             new_dir = fs.path.combine(dirname, new_dir_name)
             if not self.fs.isdir(new_dir):
                 try:
@@ -447,37 +451,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             else:
                 ok = QtWidgets.QMessageBox.warning(self, u"New Folder", u"Can't create this Folder: {}".format(new_dir))
 
-    def history_top(self):
-        """
-        Action for top dir in history_list
-        """
-        self.browse_folder(self.active_url)
-        if not self.show_save_action:
-            self.ui_SelectedName.setText(None)
-        self.selection_name()
-
-    def history_next(self):
-        """
-        Action for next dir in history_list
-        """
-        index = list(reversed(self.directory_history)).index(self.selected_dir) - 1
-        if index >= 0:
-            self.ui_DirList.setCurrentIndex(index)
-        if not self.show_save_action:
-            self.ui_SelectedName.setText(None)
-        self.selection_name()
-
-    def history_previous(self):
-        """
-        Action for previous dir in history_list
-        """
-        index = list(reversed(self.directory_history)).index(self.selected_dir) + 1
-        if index < len(self.directory_history):
-            self.ui_DirList.setCurrentIndex(index)
-        if not self.show_save_action:
-            self.ui_SelectedName.setText(None)
-        self.selection_name()
-
     def action(self):
         """
         Action on Open / Save button
